==> deepin-deb-installer_1.2.4.orig.tar.gz: deepin-deb-installer-1.2.4/translations/deepin-deb-installer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquets del Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Instal·lació en bloc</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Ha fallat la instal·lació. Si us plau, comproveu la connexió de xarxa.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Ha fallat la instal·lació. Si us plau, comproveu les actualitzacions al Centre de control.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Ha fallat la instal·lació. Espai de disc insuficient.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Ha fallat la instal·lació.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependències trencades: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>L&apos;arquitectura del paquet no coincideix.</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Arrossegeu el fitxer i deixeu-lo anar aquí.</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Selecciona el fitxer</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instal·la</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>S&apos;instal·la</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Instal·lat</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Ha fallat</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>N&apos;hi ha una altra versió instal·lada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Instal·la</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Reinstal·la</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Versió:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Instal·lació correcta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstal·lació correcta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>N&apos;hi ha una altra versió instal·lada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Ha fallat la instal·lació.</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostra els paquets que s&apos;hi relacionen.</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Segur que voleu desinstal·lar %1?
També se n&apos;eliminaran totes les dependències.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquets del Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>El Gestor de paquets del Deepin és una aplicació usada per ajudar els usuaris a instal·lar i eliminar programari local. Admet instal·lacions en bloc.</translation>
    </message>
</context>
</TS>

==> deepin-deb-installer_1.2.5.orig.tar.gz: deepin-deb-installer-1.2.5/translations/deepin-deb-installer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../debinstaller.cpp" line="74"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquets del Deepin</translation>
    </message>
    <message>
        <location filename="../debinstaller.cpp" line="239"/>
        <source>Bulk Install</source>
        <translation>Instal·lació en bloc</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../deblistmodel.cpp" line="57"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Ha fallat la instal·lació. Si us plau, comproveu la connexió de xarxa.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="59"/>
        <source>Installation failed, please check updates in Control Center</source>
        <translation>Ha fallat la instal·lació. Si us plau, comproveu les actualitzacions al Centre de control.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="61"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Ha fallat la instal·lació. Espai de disc insuficient.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="64"/>
        <source>Installation Failed</source>
        <translation>Ha fallat la instal·lació.</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="296"/>
        <location filename="../deblistmodel.cpp" line="303"/>
        <source>Broken Dependencies: %1</source>
        <translation>Dependències trencades: %1</translation>
    </message>
    <message>
        <location filename="../deblistmodel.cpp" line="299"/>
        <source>Unmatched package architecture</source>
        <translation>L&apos;arquitectura del paquet no coincideix.</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../filechoosewidget.cpp" line="53"/>
        <source>Drag and drop file here</source>
        <translation>Arrossegeu el fitxer i deixeu-lo anar aquí.</translation>
    </message>
    <message>
        <location filename="../filechoosewidget.cpp" line="80"/>
        <source>Select File</source>
        <translation>Selecciona el fitxer</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="41"/>
        <source>Display details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="58"/>
        <source>Install</source>
        <translation>Instal·la</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="59"/>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../multipleinstallpage.cpp" line="61"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../packageslistdelegate.cpp" line="102"/>
        <source>Installing</source>
        <translation>S&apos;instal·la</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="106"/>
        <source>Installed</source>
        <translation>Instal·lat</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="110"/>
        <source>Failed</source>
        <translation>Ha fallat</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="135"/>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
    <message>
        <location filename="../packageslistdelegate.cpp" line="138"/>
        <source>Other version installed: %1</source>
        <translation>N&apos;hi ha una altra versió instal·lada: %1</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="82"/>
        <source>Display details</source>
        <translation>Mostra&apos;n els detalls</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="113"/>
        <source>Install</source>
        <translation>Instal·la</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="115"/>
        <source>Remove</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="117"/>
        <source>Reinstall</source>
        <translation>Reinstal·la</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="119"/>
        <source>OK</source>
        <translation>D&apos;acord</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="121"/>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="123"/>
        <source>Done</source>
        <translation>Fet</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="138"/>
        <source>Version: </source>
        <translation>Versió:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="296"/>
        <source>Installed successfully</source>
        <translation>Instal·lació correcta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="298"/>
        <source>Uninstalled successfully</source>
        <translation>Desinstal·lació correcta</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="366"/>
        <source>Other version installed: %1</source>
        <translation>N&apos;hi ha una altra versió instal·lada: %1</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="309"/>
        <source>Uninstall Failed</source>
        <translation>Ha fallat la instal·lació.</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="131"/>
        <source>Name: </source>
        <translation>Nom:</translation>
    </message>
    <message>
        <location filename="../singleinstallpage.cpp" line="364"/>
        <source>Same version installed</source>
        <translation>N&apos;hi ha instal·lada la mateixa versió.</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Display related packages</source>
        <translation>Mostra els paquets que s&apos;hi relacionen.</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="33"/>
        <source>Collapse</source>
        <translation>Replega</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="46"/>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="48"/>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <location filename="../uninstallconfirmpage.cpp" line="101"/>
        <source>Are you sure to uninstall %1?
All dependencies will also be removed</source>
        <translation>Segur que voleu desinstal·lar %1?
També se n&apos;eliminaran totes les dependències.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>Deepin Package Manager</source>
        <translation>Gestor de paquets del Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="53"/>
        <source>Deepin Package Manager is an application used to help users install and remove local software, supports bulk install.</source>
        <translation>El Gestor de paquets del Deepin és una aplicació usada per ajudar els usuaris a instal·lar i eliminar programari local. Admet instal·lacions en bloc.</translation>
    </message>
</context>
</TS>
